==> drawpile-0.9.9.tar.gz: drawpile-0.9.9/src/client/utils/listservermodel.h <==
/*
   Drawpile - a collaborative drawing program.

   Copyright (C) 2015 Calle Laakkonen

   Drawpile is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Drawpile is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Drawpile.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LISTSERVERMODEL_H
#define LISTSERVERMODEL_H

#include <QAbstractListModel>
#include <QIcon>

namespace sessionlisting {

struct ListServer {
	QIcon icon;
	QString iconName;
	QString name;
	QString url;
	QString description;
};

class ListServerModel : public QAbstractListModel
{
	Q_OBJECT
public:
	ListServerModel(QObject *parent=0);

	int rowCount(const QModelIndex &parent=QModelIndex()) const;
	QVariant data(const QModelIndex &index, int role=Qt::DisplayRole) const;

	bool removeRows(int row, int count, const QModelIndex &parent);

	void addServer(const QString &name, const QString &url, const QString &description);

	//!  Set the favicon for the server with the given URL
	void setFavicon(const QString &url, const QImage &icon);

	//! Load server list from the settings file
	void loadServers();

	//! Save (modified) server list. This replaces the existing list
	void saveServers() const;

public slots:

private:
	QList<ListServer> _servers;
};

}

#endif // LISTSERVERMODEL_H

==> drawpile-0.9.10.tar.gz: drawpile-0.9.10/src/client/utils/listservermodel.h <==
/*
   Drawpile - a collaborative drawing program.

   Copyright (C) 2015 Calle Laakkonen

   Drawpile is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Drawpile is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Drawpile.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LISTSERVERMODEL_H
#define LISTSERVERMODEL_H

#include <QAbstractListModel>
#include <QIcon>

namespace sessionlisting {

struct ListServer {
	QIcon icon;
	QString iconName;
	QString name;
	QString url;
	QString description;
};

class ListServerModel : public QAbstractListModel
{
	Q_OBJECT
public:
	ListServerModel(bool showlocal, QObject *parent=0);

	int rowCount(const QModelIndex &parent=QModelIndex()) const;
	QVariant data(const QModelIndex &index, int role=Qt::DisplayRole) const;

	bool removeRows(int row, int count, const QModelIndex &parent);

	void addServer(const QString &name, const QString &url, const QString &description);

	//!  Set the favicon for the server with the given URL
	void setFavicon(const QString &url, const QImage &icon);

	//! Load server list from the settings file
	void loadServers();

	//! Save (modified) server list. This replaces the existing list
	void saveServers() const;

private:
	QList<ListServer> _servers;
	bool _showlocal;
};

}

#endif // LISTSERVERMODEL_H
